from .action import NHCAction

class NHCLight(NHCAction):
    def __init__(self, controller, action):
        super().__init__(controller, action)

    @property
    def is_on(self):
        """Is on."""
        return self._state > 0

    def turn_on(self, brightness=255):
        """Turn On."""
        return self._controller.execute(self.id, brightness)

    def turn_off(self):
        """Turn off."""
        return self._controller.execute(self.id, 0)

    def toggle(self):
        """Toggle on/off."""
        if self.is_on:
            return self.turn_off()

        return self.turn_on()



import setuptools

setuptools.setup(
    name='nhc',
    description='SDK for Niko Home Control',
    license='MIT',
    url='https://github.com/vandeurenglenn/nhc',
    version='0.2.15',
    author='vandeuren Glenn',
    author_email='vandeurenglenn@gmail.com',
    maintainer='vandeuren Glenn',
    maintainer_email='vandeurenglenn@gmail.com',
    long_description='Niko Home Control Client Library',
    packages=setuptools.find_packages(),
    zip_safe=False,
    install_requires=['nclib'],
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3"
    ],
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
nhcconnection.py

This is a tool to communicate with Niko Home Control.

You will have to provide an IP address and a port number.

License: MIT https://opensource.org/licenses/MIT
Source: https://github.com/NoUseFreak/niko-home-control
Author: Dries De Peuter
"""
import nclib
from .const import DEFAULT_PORT

NHC_TIMEOUT = 2000

class NHCConnection:
    """ A class to communicate with Niko Home Control. """
    def __init__(self, ip, port=DEFAULT_PORT):
        self._socket = None
        self._ip = ip
        self._port = port

    async def connect(self):
        """
        Connect to the Niko Home Control.
        """
        self._socket = nclib.Netcat((self._ip, self._port), udp=False)
        self._socket.settimeout(NHC_TIMEOUT)

    def __del__(self):
        if self._socket is not None:
            self._socket.shutdown(1)
            self._socket.close()

    def receive(self):
        """
        Receives information from the Netcat socket.
        """
        return self._socket.recv().decode()

    def read(self):
        return self._receive_until(b'\r')

    def _receive_until(self, s):
        """
        Recieve data from the socket until the given substring is observed.
        Data in the same datagram as the substring, following the substring,
        will not be returned and will be cached for future receives.
        """
        return self._socket.recv_until(s)

    def send(self, s):
        """
        Sends the given command to Niko Home Control and returns the output of
        the system.

        Aliases: write, put, sendall, send_all
        """
        self._socket.send(s.encode())
        return self.read()
